==> kubernetes-model-admissionregistration-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/NonResourceAttributesBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NonResourceAttributesBuilder extends io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesBuilder>{
  public NonResourceAttributesBuilder() {
    this(false);
  }
  public NonResourceAttributesBuilder(java.lang.Boolean validationEnabled) {
    this(new NonResourceAttributes(), validationEnabled);
  }
  public NonResourceAttributesBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<?> fluent) {
    this(fluent, false);
  }
  public NonResourceAttributesBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NonResourceAttributes(), validationEnabled);
  }
  public NonResourceAttributesBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes instance) {
    this(fluent, instance, false);
  }
  public NonResourceAttributesBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPath(instance.getPath()); 
    fluent.withVerb(instance.getVerb()); 
    this.validationEnabled = validationEnabled; 
  }
  public NonResourceAttributesBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes instance) {
    this(instance,false);
  }
  public NonResourceAttributesBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPath(instance.getPath()); 
    this.withVerb(instance.getVerb()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes build() {
    NonResourceAttributes buildable = new NonResourceAttributes(fluent.getPath(),fluent.getVerb());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NonResourceAttributesBuilder that = (NonResourceAttributesBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-admissionregistration-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/NonResourceAttributesBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NonResourceAttributesBuilder extends io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesBuilder>{
  public NonResourceAttributesBuilder() {
    this(false);
  }
  public NonResourceAttributesBuilder(java.lang.Boolean validationEnabled) {
    this(new NonResourceAttributes(), validationEnabled);
  }
  public NonResourceAttributesBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<?> fluent) {
    this(fluent, false);
  }
  public NonResourceAttributesBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NonResourceAttributes(), validationEnabled);
  }
  public NonResourceAttributesBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes instance) {
    this(fluent, instance, false);
  }
  public NonResourceAttributesBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPath(instance.getPath()); 
    fluent.withVerb(instance.getVerb()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NonResourceAttributesBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes instance) {
    this(instance,false);
  }
  public NonResourceAttributesBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPath(instance.getPath()); 
    this.withVerb(instance.getVerb()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes build() {
    NonResourceAttributes buildable = new NonResourceAttributes(fluent.getPath(),fluent.getVerb());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NonResourceAttributesBuilder that = (NonResourceAttributesBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
